# -*- coding: utf-8 -*-
# @author: leesoar

"""something."""

from anole.fake import UserAgent, Name
from anole.setting import __version__
